Module analysis

Module analysis 

Structs

AnalysisDatabase
Persistent query cache for lexing, parsing, and type checking Harn sources.
AnalysisStats
ParseOutput
SourceDigest
Deterministic content digest for a source input.
SourceId
Stable source identity used by the incremental analysis cache.
SourceVersion
Monotonic caller-owned version for a source input.
TypeCheckConfig
TypeCheckOutput

Enums

AnalysisError
SourceUpdate