harness_stdio_replacement

Function harness_stdio_replacement 

pub fn harness_stdio_replacement(name: &str) -> Option<&'static str>
Map an ambient stdio-capability builtin to its harness.stdio.* replacement so harn fix can replace the call in place once the relevant harness binding is available.