binding_pattern_names

Function binding_pattern_names 

pub fn binding_pattern_names(pattern: &BindingPattern) -> Vec<String>
Return every name introduced by a destructuring pattern, in source order. The projection is intentionally shared by the compiler and typechecker.