module_match_pattern_catalog_with_visible

Function module_match_pattern_catalog_with_visible 

pub fn module_match_pattern_catalog_with_visible(
    program: &[SNode],
    visible_type_declarations: &[SNode],
) -> MatchPatternCatalog
Build the enum catalog with declarations imported into module scope. Local declarations are registered last because they shadow imported types.