pub fn nested_callable_value_write_names(
body: &[SNode],
match_patterns: &MatchPatternCatalog,
) -> Vec<String>Expand description
Captured values whose contents may change when a nested callable executes.
pub fn nested_callable_value_write_names(
body: &[SNode],
match_patterns: &MatchPatternCatalog,
) -> Vec<String>Captured values whose contents may change when a nested callable executes.