pub fn declared_params(program: &[SNode]) -> Vec<DeclaredParam>Expand description
Collect the complete ordered parameter projection used by migration audits.
pub fn declared_params(program: &[SNode]) -> Vec<DeclaredParam>Collect the complete ordered parameter projection used by migration audits.