pub struct RuntimeScope<'scope, 'env: 'scope> { /* private fields */ }Expand description
A scope whose threads hold RUNTIME_STACK_SIZE. See scope.
Implementations
Sourceimpl<'scope, 'env> RuntimeScope<'scope, 'env>
impl<'scope, 'env> RuntimeScope<'scope, 'env>
Sourcepub fn spawn<F, T>(&self, body: F) -> ScopedJoinHandle<'scope, T>
pub fn spawn<F, T>(&self, body: F) -> ScopedJoinHandle<'scope, T>
std::thread::Scope::spawn with RUNTIME_STACK_SIZE.
Panics if the OS cannot create the thread, as the standard library does.
Sourcepub fn spawn_named<F, T>(
&self,
name: impl Into<String>,
body: F,
) -> Result<ScopedJoinHandle<'scope, T>>
pub fn spawn_named<F, T>( &self, name: impl Into<String>, body: F, ) -> Result<ScopedJoinHandle<'scope, T>>
Spawn a named scoped thread, reporting a spawn failure to the caller.