pub struct TypedParam {
pub name: String,
pub type_expr: Option<TypeExpr>,
pub default_value: Option<Box<SNode>>,
}Expand description
A parameter with an optional type annotation and optional default value.
Fields
name: Stringtype_expr: Option<TypeExpr>default_value: Option<Box<SNode>>Implementations
Sourceimpl TypedParam
impl TypedParam
Sourcepub fn names(params: &[TypedParam]) -> Vec<String>
pub fn names(params: &[TypedParam]) -> Vec<String>
Extract just the names from a list of typed params.
Sourcepub fn default_start(params: &[TypedParam]) -> Option<usize>
pub fn default_start(params: &[TypedParam]) -> Option<usize>
Return the index of the first parameter with a default value, or None.