pub struct BindingTypeInfo {
pub name: String,
pub span: Span,
pub type_expr: TypeExpr,
}Expand description
Semantic type inferred or declared for one plain local binding.
Consumers such as codemods use the declaration span as stable identity; the display-oriented inlay-hint stream intentionally omits obvious types and therefore is not a semantic analysis surface.
Fields
name: Stringspan: Spantype_expr: TypeExprTrait Implementations
Sourceimpl Clone for BindingTypeInfo
impl Clone for BindingTypeInfo
Sourcefn clone(&self) -> BindingTypeInfo
fn clone(&self) -> BindingTypeInfo
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreAuto Trait Implementations
impl Freeze for BindingTypeInfo
impl RefUnwindSafe for BindingTypeInfo
impl Send for BindingTypeInfo
impl Sync for BindingTypeInfo
impl Unpin for BindingTypeInfo
impl UnsafeUnpin for BindingTypeInfo
impl UnwindSafe for BindingTypeInfo