Structs
- Analysis
Database - Persistent query cache for lexing, parsing, and type checking Harn sources.
- Analysis
Stats - Parse
Output - Source
Digest - Deterministic content digest for a source input.
- Source
Id - Stable source identity used by the incremental analysis cache.
- Source
Version - Monotonic caller-owned version for a source input.
- Type
Check Config - Type
Check Output