pub fn binding_pattern_names(pattern: &BindingPattern) -> Vec<String>Expand description
Return every name introduced by a destructuring pattern, in source order. The projection is intentionally shared by the compiler and typechecker.
pub fn binding_pattern_names(pattern: &BindingPattern) -> Vec<String>Return every name introduced by a destructuring pattern, in source order. The projection is intentionally shared by the compiler and typechecker.