Module typechecker

Module typechecker 

Structs

TypeChecker
The static type checker.
TypeDiagnostic
A diagnostic produced by the type checker.

Enums

DiagnosticSeverity

Functions

format_type
shape_mismatch_detail
Format a type expression for display in error messages. Produce a detail string describing why a Shape type is incompatible with another Shape type — e.g. “missing field ‘age’ (int)” or “field ‘name’ has type int, expected string”. Returns None if both types are not shapes.