Structs
- Type
Checker - The static type checker.
- Type
Diagnostic - A diagnostic produced by the type checker.
Enums
Functions
- format_
type - shape_
mismatch_ detail - Format a type expression for display in error messages.
Produce a detail string describing why a Shape type is incompatible with
another Shape type — e.g. “missing field ‘age’ (int)” or “field ‘name’
has type int, expected string”. Returns
Noneif both types are not shapes.