pub struct TypeChecker { /* private fields */ }Expand description
The static type checker.
Implementations
Sourceimpl TypeChecker
impl TypeChecker
pub fn new() -> Self
Sourcepub fn with_strict_types(strict: bool) -> Self
pub fn with_strict_types(strict: bool) -> Self
Create a type checker with strict types mode. When enabled, flags unvalidated boundary-API values used in field access.
Sourcepub fn with_imported_names(self, imported: HashSet<String>) -> Self
pub fn with_imported_names(self, imported: HashSet<String>) -> Self
Attach the set of names statically introduced by cross-module imports.
Enables strict cross-module undefined-call errors: call sites that are
not builtins, not local declarations, not struct constructors, not
callable variables, and not in imported will produce a type error.
Passing None (the default) preserves pre-v0.7.12 behavior where
unresolved call names only surface via lint diagnostics. Callers
should only pass Some(set) when every import in the file resolved
— see harn_modules::ModuleGraph::imported_names_for_file.
Sourcepub fn check_with_source(
self,
program: &[SNode],
source: &str,
) -> Vec<TypeDiagnostic>
pub fn check_with_source( self, program: &[SNode], source: &str, ) -> Vec<TypeDiagnostic>
Check a program with source text for autofix generation.
Sourcepub fn check_strict_with_source(
self,
program: &[SNode],
source: &str,
) -> Vec<TypeDiagnostic>
pub fn check_strict_with_source( self, program: &[SNode], source: &str, ) -> Vec<TypeDiagnostic>
Check a program with strict types mode and source text.
Sourcepub fn check(self, program: &[SNode]) -> Vec<TypeDiagnostic>
pub fn check(self, program: &[SNode]) -> Vec<TypeDiagnostic>
Check a program and return diagnostics.
Sourcepub fn check_with_hints(
self,
program: &[SNode],
source: &str,
) -> (Vec<TypeDiagnostic>, Vec<InlayHintInfo>)
pub fn check_with_hints( self, program: &[SNode], source: &str, ) -> (Vec<TypeDiagnostic>, Vec<InlayHintInfo>)
Check a program and return both diagnostics and inlay hints.