pub struct TypeChecker { /* private fields */ }Expand description
The static type checker.
Implementations
Sourceimpl TypeChecker
impl TypeChecker
pub fn new() -> Self
Sourcepub fn check_with_source(
self,
program: &[SNode],
source: &str,
) -> Vec<TypeDiagnostic>
pub fn check_with_source( self, program: &[SNode], source: &str, ) -> Vec<TypeDiagnostic>
Check a program with source text for autofix generation.
Sourcepub fn check(self, program: &[SNode]) -> Vec<TypeDiagnostic>
pub fn check(self, program: &[SNode]) -> Vec<TypeDiagnostic>
Check a program and return diagnostics.
Sourcepub fn check_with_hints(
self,
program: &[SNode],
source: &str,
) -> (Vec<TypeDiagnostic>, Vec<InlayHintInfo>)
pub fn check_with_hints( self, program: &[SNode], source: &str, ) -> (Vec<TypeDiagnostic>, Vec<InlayHintInfo>)
Check a program and return both diagnostics and inlay hints.